***************
Mixing Patterns
***************

.. automodule:: networkx.algorithms.mixing
.. currentmodule:: networkx
.. autosummary::
   :toctree: generated/

Assortativity
-------------   
.. autosummary::
   :toctree: generated/

   degree_assortativity
   attribute_assortativity
   numeric_assortativity
   neighbor_connectivity
   degree_pearsonr

Mixing
------
.. autosummary::
   :toctree: generated/

   attribute_mixing_matrix
   degree_mixing_matrix
   degree_mixing_dict
   attribute_mixing_dict
